Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1386)

Unified Diff: checkout.py

Issue 25686005: Return unicode commit hashes in checkout.GitCheckout (Closed) Base URL: http://src.chromium.org/svn/trunk/tools/depot_tools/
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/checkout_test.py » ('j') | tests/checkout_test.py » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: checkout.py
===================================================================
--- checkout.py (revision 226480)
+++ checkout.py (working copy)
@@ -622,8 +622,8 @@
'--quiet'])
def _get_head_commit_hash(self):
- """Gets the current revision from the local branch."""
- return self._check_output_git(['rev-parse', 'HEAD']).strip()
+ """Gets the current revision (in unicode) from the local branch."""
+ return unicode(self._check_output_git(['rev-parse', 'HEAD']).strip())
def apply_patch(self, patches, post_processors=None, verbose=False):
"""Applies a patch on 'working_branch' and switches to it.
« no previous file with comments | « no previous file | tests/checkout_test.py » ('j') | tests/checkout_test.py » ('J')

Powered by Google App Engine
This is Rietveld 408576698